( cd usr/lib ; rm -rf libmlt.so )
( cd usr/lib ; ln -sf libmlt.so.0.2.2 libmlt.so )
( cd usr/lib ; rm -rf libvalerie.so )
( cd usr/lib ; ln -sf libvalerie.so.0.2.2 libvalerie.so )
( cd usr/lib ; rm -rf libmiracle.so )
( cd usr/lib ; ln -sf libmiracle.so.0.2.2 libmiracle.so )
